==> humanCHRLOC_1.12.0.tar.gz: humanCHRLOC/man/humanCHRLOC21START.Rd <==
\name{humanCHRLOC21START}
\alias{humanCHRLOC21START}
\title{An annotation data file for transciption starting locations of genes
on chromosome 21}
\description{
  humanCHRLOC21START maps LocusLink ids to the transciption starting
  locations of genes on chromosome number 21 corresponding to the
  LocusLink ids 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are LocusLink ids and values are the transciption starting location for
   genes. The starting positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors of length 1 derived from the
   smallest starting value found for the LocusLink id. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\url{http://gopher5/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Homo_sapiens/database/}. Built: No build info available.

   Package built: Sat Mar 25 23:16:34 2006
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanCHRLOC21START)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}

==> humanCHRLOC_1.14.1.tar.gz: humanCHRLOC/man/humanCHRLOC21START.Rd <==
\name{humanCHRLOC21START}
\alias{humanCHRLOC21START}
\title{An annotation data file for transciption starting locations of genes
on chromosome 21}
\description{
  humanCHRLOC21START maps Entrez Gene identifiers to the transciption starting
  locations of genes on chromosome number 21 corresponding to the
  Entrez Gene identifiers 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are Entrez Gene identifiers and values are the transciption starting location for
   genes. The starting positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors of length 1 derived from the
   smallest starting value found for the Entrez Gene identifier. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\url{http://gopher5/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Homo_sapiens/database/}. Built: No build info available.

   Package built: Wed Sep  6 12:11:10 2006
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanCHRLOC21START)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}
